==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl<A extends V1alpha1CodeRepoServiceAuthorizeCreateFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1CodeRepoServiceAuthorizeCreateFluent<A>{

    private String code;
    private Boolean getAccessToken;
    private String namespace;
    private String secretName;

    public V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl(){
    }
    public V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl(V1alpha1CodeRepoServiceAuthorizeCreate instance){
            this.withCode(instance.getCode());

            this.withGetAccessToken(instance.isGetAccessToken());

            this.withNamespace(instance.getNamespace());

            this.withSecretName(instance.getSecretName());

    }

    public String getCode(){
            return this.code;
    }

    public A withCode(String code){
            this.code=code; return (A) this;
    }

    public Boolean hasCode(){
            return this.code != null;
    }

    public A withNewCode(String arg1){
            return (A)withCode(new String(arg1));
    }

    public A withNewCode(StringBuilder arg1){
            return (A)withCode(new String(arg1));
    }

    public A withNewCode(StringBuffer arg1){
            return (A)withCode(new String(arg1));
    }

    public Boolean isGetAccessToken(){
            return this.getAccessToken;
    }

    public A withGetAccessToken(Boolean getAccessToken){
            this.getAccessToken=getAccessToken; return (A) this;
    }

    public Boolean hasGetAccessToken(){
            return this.getAccessToken != null;
    }

    public A withNewGetAccessToken(String arg1){
            return (A)withGetAccessToken(new Boolean(arg1));
    }

    public A withNewGetAccessToken(boolean arg1){
            return (A)withGetAccessToken(new Boolean(arg1));
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public A withNewNamespace(String arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuilder arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1){
            return (A)withNamespace(new String(arg1));
    }

    public String getSecretName(){
            return this.secretName;
    }

    public A withSecretName(String secretName){
            this.secretName=secretName; return (A) this;
    }

    public Boolean hasSecretName(){
            return this.secretName != null;
    }

    public A withNewSecretName(String arg1){
            return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuilder arg1){
            return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuffer arg1){
            return (A)withSecretName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl that = (V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl) o;
            if (code != null ? !code.equals(that.code) :that.code != null) return false;
            if (getAccessToken != null ? !getAccessToken.equals(that.getAccessToken) :that.getAccessToken != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl<A extends V1alpha1CodeRepoServiceAuthorizeCreateFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1CodeRepoServiceAuthorizeCreateFluent<A>{

    private String apiVersion;
    private String code;
    private Boolean getAccessToken;
    private String kind;
    private String namespace;
    private String redirectUrl;
    private String secretName;

    public V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl(){
    }
    public V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl(V1alpha1CodeRepoServiceAuthorizeCreate instance){
            this.withApiVersion(instance.getApiVersion());

            this.withCode(instance.getCode());

            this.withGetAccessToken(instance.isGetAccessToken());

            this.withKind(instance.getKind());

            this.withNamespace(instance.getNamespace());

            this.withRedirectUrl(instance.getRedirectUrl());

            this.withSecretName(instance.getSecretName());

    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getCode(){
            return this.code;
    }

    public A withCode(String code){
            this.code=code; return (A) this;
    }

    public Boolean hasCode(){
            return this.code != null;
    }

    public A withNewCode(String arg1){
            return (A)withCode(new String(arg1));
    }

    public A withNewCode(StringBuilder arg1){
            return (A)withCode(new String(arg1));
    }

    public A withNewCode(StringBuffer arg1){
            return (A)withCode(new String(arg1));
    }

    public Boolean isGetAccessToken(){
            return this.getAccessToken;
    }

    public A withGetAccessToken(Boolean getAccessToken){
            this.getAccessToken=getAccessToken; return (A) this;
    }

    public Boolean hasGetAccessToken(){
            return this.getAccessToken != null;
    }

    public A withNewGetAccessToken(String arg1){
            return (A)withGetAccessToken(new Boolean(arg1));
    }

    public A withNewGetAccessToken(boolean arg1){
            return (A)withGetAccessToken(new Boolean(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public A withNewNamespace(String arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuilder arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1){
            return (A)withNamespace(new String(arg1));
    }

    public String getRedirectUrl(){
            return this.redirectUrl;
    }

    public A withRedirectUrl(String redirectUrl){
            this.redirectUrl=redirectUrl; return (A) this;
    }

    public Boolean hasRedirectUrl(){
            return this.redirectUrl != null;
    }

    public A withNewRedirectUrl(String arg1){
            return (A)withRedirectUrl(new String(arg1));
    }

    public A withNewRedirectUrl(StringBuilder arg1){
            return (A)withRedirectUrl(new String(arg1));
    }

    public A withNewRedirectUrl(StringBuffer arg1){
            return (A)withRedirectUrl(new String(arg1));
    }

    public String getSecretName(){
            return this.secretName;
    }

    public A withSecretName(String secretName){
            this.secretName=secretName; return (A) this;
    }

    public Boolean hasSecretName(){
            return this.secretName != null;
    }

    public A withNewSecretName(String arg1){
            return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuilder arg1){
            return (A)withSecretName(new String(arg1));
    }

    public A withNewSecretName(StringBuffer arg1){
            return (A)withSecretName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl that = (V1alpha1CodeRepoServiceAuthorizeCreateFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (code != null ? !code.equals(that.code) :that.code != null) return false;
            if (getAccessToken != null ? !getAccessToken.equals(that.getAccessToken) :that.getAccessToken != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            if (redirectUrl != null ? !redirectUrl.equals(that.redirectUrl) :that.redirectUrl != null) return false;
            if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
            return true;
    }




}
